# -*- coding: utf-8 -*-
"""
Created on Mon Mar 19 16:52:33 2018

@author: florent
"""

import numpy as np
import matplotlib.pyplot as plt
from SG6042Lib import PolaireSG6042Re1e5 as Polaire
plt.rc('text', usetex=True)
plt.close('all')
#----------------------------------------------------------------------------#
# CDC et contraintes
# V 10 m/s, P=5W rho=1.2kg/m3
# Vitesse rotation maxi 5000 rpm
# Npales de 2 à 6
# Corde minimale 20mm (contrainte epaisseur 10% > 2mm)
#----------------------------------------------------------------------------#

V=10 # Vitesse infini amont (m/s)
rho=1.2 # Masse volumique air (kg/m3)
mu=1.8e-5 # Viscosite dynamique air (Pa.s)
P=5 # Puissance recuperee (W)

#----------------------------------------------------------------------------#
# Sauvegarde dans le format npz : vous pouvez changer le nom du fichier
#----------------------------------------------------------------------------#
outfile='MonNom'

#----------------------------------------------------------------------------#
# Parametres libres
#----------------------------------------------------------------------------#

HubRatio= # Rapport Rhub/Rtip
Lambda= # Rapidité spécifique
B= # Nombre de pales
a= # Facteur d'induction axial
Cpest= # Estimation du coefficient de puissance
alpha= # Angle d'attaque

#----------------------------------------------------------------------------#
# Utilisation de la librairie SG6042:
# Les lignes suivantes renvoient les coefficients
# de portance et de trainee en fonction de l'angle d'incidence
# a partir d'un fit polynomial de la polaire
#----------------------------------------------------------------------------#
zaz=Polaire(alpha)
Cl=zaz[0]
Cd=zaz[1]

#----------------------------------------------------------------------------#
# A VOUS DE JOUER
#----------------------------------------------------------------------------#

Rtip=
Rhub=HubRatio*Rtip
omega= # Vitesse de rotation en rad/s
# On cree un tableau de 11 points pour discretiser la pale du pied (hub)
# a la tete de pale (tip)
r=np.linspace(Rhub,Rtip,num=11) 
theta= # Calage des profils
c= # Corde des profils

#----------------------------------------------------------------------------#
# Export en format npz (zipped numpy)
#----------------------------------------------------------------------------#
np.savez(outfile,r,theta,c)

#----------------------------------------------------------------------------#
# Pour information (affichage console):
# Vitesses relatives en pied, en milieu et en tete de pale
#----------------------------------------------------------------------------#
Whub=(V**2*(1-a)**2+(omega*Rhub)**2)**0.5
Wtip=(V**2*(1-a)**2+(omega*Rtip)**2)**0.5
Wmid=(V**2*(1-a)**2+(omega*r[np.int(r.size/2)])**2)**0.5
# Nombres de Reynolds correspondants
Rehub=Whub*rho*l1[0]/mu
Retip=Wtip*rho*l1[-1]/mu
Remid=Wmid*rho*l1[np.int(r.size/2)]/mu

#----------------------------------------------------------------------------#
# Sorties Console
#----------------------------------------------------------------------------#
print("Rtip=", np.around(Rtip*1000,1), "mm")
print("Rhub=", np.around(Rhub*1000,1), "mm")
print("Blade Length=", np.around((Rtip*1000-Rhub*1000),1), "mm")
print("N=", np.around(omega/2/np.pi*60,1), "rpm")
print("Torque=", np.around(P/omega,3), "N.m")
print("Cp=", np.around(Cpest,3))
print("Mid Chord=", np.around(l1[np.int(r.size/2)]*1000,1), "mm")
print("Mid Chord Reynolds number=", np.around(Remid/1000,1)*1000)
print("Tip Reynolds number=", np.around(Retip/1000,1)*1000)


#----------------------------------------------------------------------------#
# Sorties graphiques:
# Fig1 : corde fonction du rayon
# Fig2 : calage fonction du rayon
#----------------------------------------------------------------------------#
fig1=plt.figure(1)
ax=fig1.gca()
ax.plot(r*1000,l1*1000)
ax.set_xlabel('Radius (mm)')
ax.set_ylabel('Chord lenght (mm)')

fig2=plt.figure(2)
ax=fig2.gca()
ax.plot(r*1000,theta)
ax.set_xlabel('Radius (mm)')
ax.set_ylabel('Blade angle (deg)')